@@ -6,5 +6,5 @@ from xlsx_lib.domain.tightening_specifications.part_screw import Screw
 
 
 class ElementPart(CamelModel):
-    name: str
+    name: Optional[str]
     screws: Optional[List[Screw]]
